==> qtjambi-texttospeech-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiTextToSpeech/QTextToSpeechEngine_shell.h <==
#ifndef QTEXTTOSPEECHENGINE_SHELL_H
#define QTEXTTOSPEECHENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtTextToSpeech/qtexttospeechengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtTextToSpeech/qtexttospeech.h>
#include <QtTextToSpeech/qvoice.h>
#include "hashes.h"
#include <QtJambi/RegistryAPI>


class QTextToSpeechEngine_shell : public QTextToSpeechEngine, public QtJambiShellInterface
{
public:
    QTextToSpeechEngine_shell(QObject* parent0 = nullptr);
    ~QTextToSpeechEngine_shell() override;

    QList<QLocale> availableLocales() const override;
    QList<QVoice> availableVoices() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QTextToSpeech::ErrorReason errorReason() const override;
    QString errorString() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QLocale locale() const override;
    void pause(QTextToSpeech::BoundaryHint boundaryHint0) override;
    double pitch() const override;
    double rate() const override;
    void resume() override;
    void say(const QString& text0) override;
    bool setLocale(const QLocale& locale0) override;
    bool setPitch(double pitch0) override;
    bool setRate(double rate0) override;
    bool setVoice(const QVoice& voice0) override;
    bool setVolume(double volume0) override;
    QTextToSpeech::State state() const override;
    void stop(QTextToSpeech::BoundaryHint boundaryHint0) override;
    void timerEvent(QTimerEvent* event0) override;
    QVoice voice() const override;
    double volume() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextToSpeechEngine_access : public QTextToSpeechEngine
{
    static jobject __qt_createVoice_cref_QString_cref_QLocale_QVoice_Gender_QVoice_Age_cref_QVariant(JNIEnv *__jni_env, jstring name0, QtJambiNativeID locale1, jint gender2, jint age3, jobject data4);
    static jobject __qt_voiceData_cref_QVoice(JNIEnv *__jni_env, QtJambiNativeID voice0);
    jobject __qt_availableLocales(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_availableVoices(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_errorReason(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_errorString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_locale(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_pause_QTextToSpeech_BoundaryHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint boundaryHint0);
    jdouble __qt_pitch(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jdouble __qt_rate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_say_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
    jboolean __qt_setLocale_cref_QLocale(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID locale0);
    jboolean __qt_setPitch_double(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble pitch0);
    jboolean __qt_setRate_double(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble rate0);
    jboolean __qt_setVoice_cref_QVoice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID voice0);
    jboolean __qt_setVolume_double(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble volume0);
    jint __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop_QTextToSpeech_BoundaryHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint boundaryHint0);
    jobject __qt_voice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jdouble __qt_volume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QTEXTTOSPEECHENGINE_SHELL_H

==> qtjambi-texttospeech-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiTextToSpeech/QTextToSpeechEngine_shell.h <==
#ifndef QTEXTTOSPEECHENGINE_SHELL_H
#define QTEXTTOSPEECHENGINE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtTextToSpeech/qtexttospeechengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtTextToSpeech/qtexttospeech.h>
#include <QtTextToSpeech/qvoice.h>
#include "hashes.h"
#include <QtJambi/RegistryAPI>


class QTextToSpeechEngine_shell : public QTextToSpeechEngine, public QtJambiShellInterface
{
public:
    QTextToSpeechEngine_shell(QObject* parent0 = nullptr);
    ~QTextToSpeechEngine_shell() override;

    QList<QLocale> availableLocales() const override;
    QList<QVoice> availableVoices() const override;
    QTextToSpeech::Capabilities capabilities() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QTextToSpeech::ErrorReason errorReason() const override;
    QString errorString() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QLocale locale() const override;
    void pause(QTextToSpeech::BoundaryHint boundaryHint0) override;
    double pitch() const override;
    double rate() const override;
    void resume() override;
    void say(const QString& text0) override;
    bool setLocale(const QLocale& locale0) override;
    bool setPitch(double pitch0) override;
    bool setRate(double rate0) override;
    bool setVoice(const QVoice& voice0) override;
    bool setVolume(double volume0) override;
    QTextToSpeech::State state() const override;
    void stop(QTextToSpeech::BoundaryHint boundaryHint0) override;
    void synthesize(const QString& text0) override;
    void timerEvent(QTimerEvent* event0) override;
    QVoice voice() const override;
    double volume() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextToSpeechEngine_access : public QTextToSpeechEngine
{
    static jobject __qt_createVoice_cref_QString_cref_QLocale_QVoice_Gender_QVoice_Age_cref_QVariant(JNIEnv *__jni_env, jstring name0, QtJambiNativeID locale1, jint gender2, jint age3, jobject data4);
    static jobject __qt_voiceData_cref_QVoice(JNIEnv *__jni_env, QtJambiNativeID voice0);
    jobject __qt_availableLocales(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_availableVoices(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_capabilities(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_errorReason(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_errorString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_locale(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_pause_QTextToSpeech_BoundaryHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint boundaryHint0);
    jdouble __qt_pitch(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jdouble __qt_rate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_say_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
    jboolean __qt_setLocale_cref_QLocale(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID locale0);
    jboolean __qt_setPitch_double(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble pitch0);
    jboolean __qt_setRate_double(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble rate0);
    jboolean __qt_setVoice_cref_QVoice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID voice0);
    jboolean __qt_setVolume_double(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble volume0);
    jint __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop_QTextToSpeech_BoundaryHint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint boundaryHint0);
    void __qt_synthesize_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring text0);
    jobject __qt_voice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jdouble __qt_volume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QTEXTTOSPEECHENGINE_SHELL_H
